#
# spec file for package pfstools
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pfstools
Version:        1.8.4
Release:        16.5
Source:         %{name}-%{version}.tar.bz2
Patch:          %{name}-octave.patch
Patch1:         %{name}-gcc.patch
Patch2:         pfstools-stringcompare.patch
Patch4:         pfstools-stdlib.patch
Patch5:         pfstools-1.8.1-fix-return-in-nonvoid.patch
Patch6:         pfstools-no-debug-mangling.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://www.mpi-sb.mpg.de/resources/pfstools/
BuildRequires:  Mesa
BuildRequires:  OpenEXR-devel
BuildRequires:  blas
BuildRequires:  fftw3-devel
BuildRequires:  freeglut-devel
BuildRequires:  lapack
BuildRequires:  libMagick++-devel
BuildRequires:  libnetpbm-devel
BuildRequires:  libqt4-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(glu)
#BuildRequires:  octave-devel
Requires:       dcraw
Summary:        High Dynamic Range Images and Video manipulation tools
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Multimedia/Other

%description
pfstools package is a set of command line (and one GUI) programs for
reading, writing, manipulating and viewing high-dynamic range (HDR)
images and video frames. All programs in the package exchange data
using a simple generic file format (pfs) for HDR data. The concept of
the pfstools is similar to netpbm package for low-dynamic range images.

%package devel
Requires:       %{name} = %{version}
Summary:        High Dynamic Range Images and Video manipulation tools
License:        GPL-2.0+
Group:          Development/Libraries/C and C++

%description devel
pfstools package is a set of command line (and one GUI) programs for
reading, writing, manipulating and viewing high-dynamic range (HDR)
images and video frames. All programs in the package exchange data
using a simple generic file format (pfs) for HDR data. The concept of
the pfstools is similar to netpbm package for low-dynamic range images.

%prep
%setup -q
%patch
%patch1
%patch2
%patch4
%patch5 -p1
%patch6 -p1

%build
autoreconf -f -i
%configure --disable-static --with-pic --disable-octave --with-qtdir=/usr
make %{?jobs:-j%jobs}

%install
make DESTDIR=$RPM_BUILD_ROOT install
%{__rm} -f %{buildroot}%{_libdir}/*.la
grep -r include %{buildroot}%{_includedir} | awk -F: '{print $2}'

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING INSTALL NEWS README TODO
%{_bindir}/*
%{_mandir}/man?/*
%{_libdir}/*.so.*
/usr/share/%{name}
# temporary removed 
#%{_libdir}/octave/*/site/oct/*/pfstools
#%_datadir/octave/*/site/m/pfstools

%files devel
%defattr(-,root,root)
%doc doc/{pfs_format_spec.pdf,faq.txt}
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Mon Apr 22 2013 dimstar@opensuse.org
- Add pfstools-no-debug-mangling.patch: don't drop occurences of
  "-g" from CFLAGS. It destroys -grecord-gcc-flags.
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit build dependency on glu
* Sat May 12 2012 anixx@opensuse.org
- fix build by correcting the build dependency on libMagick++-devel
* Tue Mar  6 2012 tabraham@novell.com
- refreshed pfstools-octave.patch
- Update to version 1.8.4
  * fixed: SegFault from pfsview when switching channels
  * fixed: quoted arguments in pfsin/pfsout/pfsv/pfsindcraw/
    pfsinmulti (fixes bug 3279342)
- Changes from version 1.8.3
  * fixed: pfsdisplayfunction properly interpolates display LUT
  * fixed: bug #3080304 - configure uses non-portable test(1) syntax
  * fixed: bug #1766263 - pfsinhdrgen fails silently on pfsin
    failure. - partially
  * fixed: pfsview the entire code converted from qt3 to qt4 (fixes
    bug #3127946)
  * fixed: "Fit window to content" works again in pfsview
  * added: window icon in pfsview
  * added: improved image file saving in pfsview
- Changes from version 1.8.2
  * fixed: compiler incompatibility issue in pfspanoramic.cpp
  * fixed: bug #2953028 "gcc 4.4.1 const cast error"
  * fixed: spaces were improperly escaped in pfsin / pfsout (thanks
    to Timo)
  * added: new improved hdrhtml template from hdrlabs.com (thanks
    to Christian)
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Mar  2 2010 puzel@novell.com
- add pfstools-1.8.1-fix-return-in-nonvoid.patch
* Thu Aug  6 2009 postadal@suse.cz
- updated to version 1.8.1
  * pfsouthdrhtml for generating web pages with an HDR viewer
  * pfsview shows in the status bar current exposure for the dynamic
    range window (relative to Y=1)
- updated pfstools-gcc.patch (bnc#445426)
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Sun Sep  7 2008 postadal@suse.cz
- updated to version 1.6.5
  * mostly improvements in the matlab interface (thanks to Neil
    Alldrin). Also two patches ported from Debian (dcraw and octave3.0)
* Mon Apr 14 2008 postadal@suse.cz
- updated to version 1.6.4
  * fixed: pfsinopenexr can now read files that has data window < display window
  * fixed: pfs library can handle channel names up to 32 characters (was 8)
  * updated: pfs specification - max string lengths and format of custom channel names
  * security fix: fscanf in rgbeio.cpp (thanks to Stefan and Ludwig)
  * bugfix: pfsview - segfault when switching channels
  * fixed: pfsview - color readout in the status line refreshed when new channel
    or frame loaded
  * added: matlab/pfs_write_luminance.m
  * bugfix: rgbeio - header read properly when the first byte is 0x20
  * bugfix: rgbeio - fix misinterpreted rle-compresses lines
  * fixed: buffer overflow vulnerability in rgbeio.cpp
  * fixed: compilation issues with gcc-4.3 - missing includes
- removed obsoleted patch secfix_298770.patch
* Wed Dec  5 2007 nadvornik@suse.cz
- fixed includes for gcc 4.3 (stdlib.patch)
* Tue Aug 14 2007 postadal@suse.cz
- fixed vulnerability when reading Radiance RGBE (*.hdr) files
  [#298770] (secfix_298770.patch)
* Thu Aug  9 2007 ro@suse.de
- added libnetpbm-devel to buildreq
* Mon Aug  6 2007 postadal@suse.cz
- updated to version 1.6.1
  * bug-fix release, with a major fix for the sRGB color transform
- temporary removed octave support (changed octave API)
* Mon Jun 11 2007 ro@suse.de
- avoid stringcompare with char literal
* Tue Jun  5 2007 ro@suse.de
- added octave-devel to buildreq
* Mon May  7 2007 postadal@suse.cz
- updated to version 1.6.1
  * improved image readers/writes can load LDR images with the alpha channel
  * pfsglview - new OpenGL HDR viewer
  * pfsindcraw - dcraw integration
- added dcraw to requires
- run ldconfig
* Thu Feb  8 2007 ro@suse.de
- added defattr to devel package
* Mon Feb  5 2007 ro@suse.de
- run full autoreconf to fix build on x86_64
* Thu Dec 21 2006 ro@suse.de
- fix configure arguments and such prevent rpath for //usr/lib
* Fri Oct 27 2006 postadal@suse.cz
- added ImageMagick*-devel to BuildRequires (for pfs[in/out]imgmagick)
* Mon Oct 23 2006 postadal@suse.cz
- fixed invalid pure specifier (gcc.patch)
* Wed Oct 11 2006 postadal@suse.cz
- packed pfs_format_spec.pdf and faq.txt to -devel
* Sat Oct  7 2006 postadal@suse.cz
- initial version 1.5
- fixed linking octave (octave.patch)
- fixed gcc issues (gcc.patch)
